@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2019, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -39,8 +39,8 @@
  *
  * @ingroup data
  */
-#ifndef _ITEM_H
-#define _ITEM_H
+#ifndef INCLUDED_ITEM_H
+#define INCLUDED_ITEM_H
 
 #include "scope.h"
 
@@ -215,4 +215,4 @@ void    put_metadata(property_tree::ptree& pt, const item_t::string_map& metadat
 
 } // namespace ledger
 
-#endif // _ITEM_H
+#endif // INCLUDED_ITEM_H
